## dbt-adapters 1.16.3 - July 21, 2025

### Fixes

- Update dbt snapshot staging table creation to handle new source columns when using hard_deletes == 'new_record'  ([#852](https://github.com/dbt-labs/dbt-adapters/issues/852))
- update alter_relation_add_remove_columns to quote column names ([#63](https://github.com/dbt-labs/dbt-adapters/issues/63))

### Under the Hood

- gracefully handle null database in _catalog_filter_schemas ([#1216](https://github.com/dbt-labs/dbt-adapters/issues/1216))
